%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% SingleL_Helm
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Reference:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function S = SingleL_Helm(k,Omega, D) 

M_Omega=Omega.nbPoints;
M = D.nbPoints;
S = zeros(M_Omega, M);

green = @(k,x,y) -1i/4*besselh(0,1,k*sqrt(x.^2+y.^2));

if Omega.points==D.points
    for j = 1:M
        S(j,1:j-1) = D.sigma(1:j-1).*green(k,D.points(1,j)-D.points(1,1:j-1),D.points(2,j)-D.points(2,1:j-1));
        S(j,j+1:M) = D.sigma(j+1:M).*green(k,D.points(1,j)-D.points(1,j+1:M),D.points(2,j)-D.points(2,j+1:M));
        S(j,j) = -1i/4*D.sigma(j)*(2*1i*(-psi(1)+log(D.sigma(j)*k/4)-1)/pi+1);       
    end   
else
   for j = 1:M_Omega        
         S(j,:) = green(k,Omega.points(1,j)-D.points(1,:),Omega.points(2,j)-D.points(2,:)).*D.sigma(1:M);
   end 
end

end

